==> links_v0.7.0b.zip: links/config/config.php <==
<?php
/////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//              Configuration file for Links Ver0.7
//                Copyright (C) 2002-2003  WHITEWING,Team-act
//            <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This program is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//////////////////////////////////////////////////////////////////////////////

//Language
define("_Lang","japanese");

//Language(for mb_language() )
define("_Mb_Lang","ja");

//Login name (admin.php)
define("_Admin_Name","admin");

//Password(md5) (admin.php)
define("_Admin_Pass","f1c1592588411002af340cbaedd6fc33");

//Homepage
define("_HomePage","http://w-wing.net/");

//Admin Mail
define("_Admin_mail","whitewing@w-wing.net");

//Mode(0:Visitor mode , 1:Admin mode)
define("_Mode",0);

//Back URL
define("_BackURL","../../");

//Category file(Path)
define("_Def_Ctgy","./config/ctgy.cgi");

//Site file(Path)
define("_Def_Site","./config/site.cgi");

//Latest file(Path)
define("_Def_New","./config/new.cgi");

//NEW LINKS(sec)
define("_NEW",7*24*60*60);

//Time difference(sec)
define("_JISA",9*60*60);

//Do you send mail when someone registers? (0: No , 1:Yes)
define("_Mail",0);

//Tag (Comment) (0: strip tags , 1:available , 2:escape tags )
define("_Tag",2);

//<br /> (Comment) (0: strip , 1:available)
define("_Br",1);

//Auto Link (Comment) (0: disable , 1:available)
define("_Auto_link",0);

//REFERER Check(0:disable , 1:able)
define("_Ref_Check",0);

//strip \ (by magic_quotes) (0: OFF , 1: ON)
define("_MQ",0);

//Number of displaying links by a page
define("_VP",10);

//Counter(0:non counter mode , 1:counter mode)
define("_Counter",1);

//Proxy(0:normal mode , 1:proxy block mode)
define("_Proxy",0);

//Gzip compress(0:OFF , 1:ON)
define("_gzip",0);

//nobanner image(path)
define("_No_Banner","./images/nobanner.jpg");

?>

==> links_v0.7.3a.zip: links/config/config.php <==
<?php

//Language
define("_Lang","japanese");

//Language(for mb_language() )
define("_Mb_Lang","ja");

//Login name (admin.php)
define("_Admin_Name","admin");

//Password(md5) (admin.php)
define("_Admin_Pass","f1c1592588411002af340cbaedd6fc33");

//Homepage
define("_HomePage","http://w-wing.net/");

//Admin Mail
define("_Admin_mail","whitewing@w-wing.net");

//Mode(0:Visitor mode , 1:Admin mode)
define("_Mode",0);

//Back URL
define("_BackURL","../../");

//Category file(Path)
define("_Def_Ctgy","./config/ctgy.cgi");

//Site file(Path)
define("_Def_Site","./config/site.cgi");

//Latest file(Path)
define("_Def_New","./config/new.cgi");

//NEW LINKS(sec)
define("_NEW",7*24*60*60);

//Time difference(sec)
define("_JISA",9*60*60);

//Do you send mail when someone registers? (0: No , 1:Yes)
define("_Mail",0);

//Tag (Comment) (0: strip tags , 1:available , 2:escape tags )
define("_Tag",2);

//<br /> (Comment) (0: strip , 1:available)
define("_Br",1);

//Auto Link (Comment) (0: disable , 1:available)
define("_Auto_link",0);

//REFERER Check(0:disable , 1:able)
define("_Ref_Check",0);

//strip \ (by magic_quotes) (0: OFF , 1: ON)
define("_MQ",1);

//Number of displaying links by a page
define("_VP",10);

//Counter(0:non counter mode , 1:counter mode)
define("_Counter",1);

//Proxy(0:normal mode , 1:proxy block mode)
define("_Proxy",0);

//Gzip compress(0:OFF , 1:ON)
define("_gzip",0);

//nobanner image(path)
define("_No_Banner","./images/nobanner.jpg");

//Search System(0:disable  1:able)
define("_Search",1);

?>
